#
# spec file for package dippi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.cassidyjames.dippi
Name:           dippi
Version:        4.1.0
Release:        1.2
Summary:        Tool for calculating display info like DPI and aspect ratio
License:        GPL-3.0-or-later
URL:            https://github.com/cassidyjames/dippi
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gettext-runtime >= 0.19.7
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 1.3.2
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)

%description
A tool to analyze displays and to input a few details and figure out the aspect
ratio, DPI, and other details of a particular display. Can be used to decide
which laptop or external monitor to purchase, and if it would be considered
HiDPI.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/icons/hicolor/symbolic/apps/%{appid}-symbolic.svg
%{_datadir}/metainfo/%{appid}.metainfo.xml

%files lang -f %{appid}.lang

%changelog
* Sun Nov 17 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 4.1.0:
  * Consistently use the "analyse" spelling in British and Australian English
  * Fix deprecated top-level developer_name in AppData XML
  * Lighter icon
- update to 4.0.6:
  * Fix crash when width/height is set to 0
  * Update for GNOME 45
- update to 4.0.5:
  * update for GNOME 44
  * updated translations
- update to 4.0.2:
  * Fix About window when closing and re-opening it
- update to 4.0.1:
  * Added “About” window
  * Improved text legibility
  * Update runtime to GNOME 43
  * updated translations
  * Improvements to developer tools to make translations easier to keep up to date
- update to 4.0.0:
  * move to gtk4, abandoning granite version
- update spec file for Leap 16.0:
  * remove %%suse_update_desktop_file
  * renew buildrequires, since the project moved to gtk4/gnome
  * remove HiDPI workaround
* Sun Feb 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.1.4:
  * Update Stripe key
  * Stricter sandboxing
  * Update Stripe key
* Sat Nov 20 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.1.2:
  * Add "calculator" category to launcher
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.1.1:
  * Under-the-hood packaging updates for elementary OS 6
  * The Adventure of Link: you can now share Dippi results as a
    link so anyone can see all the details and make their own
    calculations. Plus:
  * More details on launch
  * Bolded sections of descriptions for easier skimmability
  * Fix window resizing for different results
  * Animate between results
  * Port to elementary OS 6
  * Follow the dark style preference
  * Drag window from anywhere
  * Refreshed typography and design
* Wed Feb 19 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.7.4:
  * Create release.yml
  * Create lint.yml
  * Create gettext.yml
  * Create compress-images.yml
  * Remove debian packaging from in-tree
  * Update .travis.yml
  * Prefer dark (#72)
  * Update com.github.cassidyjames.dippi.appdata.xml.in (#71)
* Mon Apr 15 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.7.3:
  * Updated translations
* Wed Jan  9 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.7.2:
  * Comment out problematic "contact" url for now
  * Update com.github.cassidyjames.dippi.appdata.xml.in
  * Add help and contact URLs
  * Add donation URL
  * Fix app-id & add some missings tags (#68)
* Mon Nov 19 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.7.1:
  * Support dark preference if it exists (#66)
  * Update README.md
* Sun Jul  1 2018 avvissu@yandex.by
- Update to 2.7.0:
  * Whitespace fixes
- Switch to metainfo from appdata
* Sun Jun 10 2018 jengelh@inai.de
- Use noun phrasing in descriptions.
* Sat Apr 21 2018 avvissu@yandex.by
- Update to 2.6.3:
  * Update appdata
* Sat Apr 14 2018 avvissu@yandex.by
- Update to 2.6.2:
  * Update lt.po (#62)
* Mon Mar 26 2018 avvissu@yandex.by
- Update to 2.6.1:
  * Fix deprecation warning for set accel
  * Prep for tiny release
  * Clear Resolution Label when invalid (#61)
  * Prep for new release (#60)
  * Missed one
  * Force update to new badges
  * Split out into Utils (#58)
  * Fix error in appdata and bump version
  * Fix editoronfig
  * Actually update travis deps
  * Better editorconfig
  * Add editorconfig
* Fri Feb  9 2018 avvissu@yandex.by
- Update to 2.5.4:
  * Update README.md
  * Update com.github.cassidyjames.dippi.appdata.xml.in
  * Update appdata with new release
  * Set a size of the main grid (#53)
  * Prepare for new release
  * Add process-completed to GResource
* Sat Jan 20 2018 avvissu@yandex.by
- Update to 2.5.1:
  * Prep appdata for new release
  * Actually add all icon sizes
  * Try out new ranges
  * Add OARS data
  * Update es.po (#48)
- Add the package with translations
* Mon Jan 15 2018 avvissu@yandex.by
- Initial package
